==> openshift-model-6.7.0-sources.jar: io/fabric8/openshift/api/model/PodSecurityPolicySubjectReviewStatusBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PodSecurityPolicySubjectReviewStatusBuilder extends PodSecurityPolicySubjectReviewStatusFluentImpl<PodSecurityPolicySubjectReviewStatusBuilder> implements VisitableBuilder<PodSecurityPolicySubjectReviewStatus,PodSecurityPolicySubjectReviewStatusBuilder>{
  public PodSecurityPolicySubjectReviewStatusBuilder() {
    this(false);
  }
  public PodSecurityPolicySubjectReviewStatusBuilder(Boolean validationEnabled) {
    this(new PodSecurityPolicySubjectReviewStatus(), validationEnabled);
  }
  public PodSecurityPolicySubjectReviewStatusBuilder(PodSecurityPolicySubjectReviewStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public PodSecurityPolicySubjectReviewStatusBuilder(PodSecurityPolicySubjectReviewStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PodSecurityPolicySubjectReviewStatus(), validationEnabled);
  }
  public PodSecurityPolicySubjectReviewStatusBuilder(PodSecurityPolicySubjectReviewStatusFluent<?> fluent,PodSecurityPolicySubjectReviewStatus instance) {
    this(fluent, instance, false);
  }
  public PodSecurityPolicySubjectReviewStatusBuilder(PodSecurityPolicySubjectReviewStatusFluent<?> fluent,PodSecurityPolicySubjectReviewStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAllowedBy(instance.getAllowedBy());
      fluent.withReason(instance.getReason());
      fluent.withTemplate(instance.getTemplate());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PodSecurityPolicySubjectReviewStatusBuilder(PodSecurityPolicySubjectReviewStatus instance) {
    this(instance,false);
  }
  public PodSecurityPolicySubjectReviewStatusBuilder(PodSecurityPolicySubjectReviewStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAllowedBy(instance.getAllowedBy());
      this.withReason(instance.getReason());
      this.withTemplate(instance.getTemplate());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PodSecurityPolicySubjectReviewStatusFluent<?> fluent;
  Boolean validationEnabled;
  public PodSecurityPolicySubjectReviewStatus build() {
    PodSecurityPolicySubjectReviewStatus buildable = new PodSecurityPolicySubjectReviewStatus(fluent.getAllowedBy(),fluent.getReason(),fluent.getTemplate());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-6.8.0-sources.jar: io/fabric8/openshift/api/model/PodSecurityPolicySubjectReviewStatusBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PodSecurityPolicySubjectReviewStatusBuilder extends PodSecurityPolicySubjectReviewStatusFluent<PodSecurityPolicySubjectReviewStatusBuilder> implements VisitableBuilder<PodSecurityPolicySubjectReviewStatus,PodSecurityPolicySubjectReviewStatusBuilder>{
  public PodSecurityPolicySubjectReviewStatusBuilder() {
    this(false);
  }
  public PodSecurityPolicySubjectReviewStatusBuilder(Boolean validationEnabled) {
    this(new PodSecurityPolicySubjectReviewStatus(), validationEnabled);
  }
  public PodSecurityPolicySubjectReviewStatusBuilder(PodSecurityPolicySubjectReviewStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public PodSecurityPolicySubjectReviewStatusBuilder(PodSecurityPolicySubjectReviewStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PodSecurityPolicySubjectReviewStatus(), validationEnabled);
  }
  public PodSecurityPolicySubjectReviewStatusBuilder(PodSecurityPolicySubjectReviewStatusFluent<?> fluent,PodSecurityPolicySubjectReviewStatus instance) {
    this(fluent, instance, false);
  }
  public PodSecurityPolicySubjectReviewStatusBuilder(PodSecurityPolicySubjectReviewStatusFluent<?> fluent,PodSecurityPolicySubjectReviewStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new PodSecurityPolicySubjectReviewStatus());

    if (instance != null) {
      fluent.withAllowedBy(instance.getAllowedBy());
      fluent.withReason(instance.getReason());
      fluent.withTemplate(instance.getTemplate());
      fluent.withAllowedBy(instance.getAllowedBy());
      fluent.withReason(instance.getReason());
      fluent.withTemplate(instance.getTemplate());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PodSecurityPolicySubjectReviewStatusBuilder(PodSecurityPolicySubjectReviewStatus instance) {
    this(instance,false);
  }
  public PodSecurityPolicySubjectReviewStatusBuilder(PodSecurityPolicySubjectReviewStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new PodSecurityPolicySubjectReviewStatus());

    if (instance != null) {
      this.withAllowedBy(instance.getAllowedBy());
      this.withReason(instance.getReason());
      this.withTemplate(instance.getTemplate());
      this.withAllowedBy(instance.getAllowedBy());
      this.withReason(instance.getReason());
      this.withTemplate(instance.getTemplate());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PodSecurityPolicySubjectReviewStatusFluent<?> fluent;
  Boolean validationEnabled;
  public PodSecurityPolicySubjectReviewStatus build() {
    PodSecurityPolicySubjectReviewStatus buildable = new PodSecurityPolicySubjectReviewStatus(fluent.buildAllowedBy(),fluent.getReason(),fluent.buildTemplate());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
